#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .limit_pressure_correction_gradient import limit_pressure_correction_gradient as limit_pressure_correction_gradient_cls

class skewness_correction(Group):
    """
    Skewness correction related stabiity controls for multiphase flow.
    """

    fluent_name = "skewness-correction"

    child_names = \
        ['limit_pressure_correction_gradient']

    _child_classes = dict(
        limit_pressure_correction_gradient=limit_pressure_correction_gradient_cls,
    )

    return_type = "<object object at 0x7fad5c967f10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .thin_film import thin_film as thin_film_cls
from .liquid_vof_factor import liquid_vof_factor as liquid_vof_factor_cls

class boiling_parameters(Group):
    """
    Multiphase boiling parameters menu.
    """

    fluent_name = "boiling-parameters"

    child_names = \
        ['thin_film', 'liquid_vof_factor']

    _child_classes = dict(
        thin_film=thin_film_cls,
        liquid_vof_factor=liquid_vof_factor_cls,
    )

    return_type = "<object object at 0x7f0b2c4fb320>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class dynamic_energy_flux(Boolean):
    """
    Enable/disable the dynamic sub-grid scale turbulent Prandtl Number.
    """

    fluent_name = "dynamic-energy-flux"

    return_type = "<object object at 0x7fad5e815790>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .file import file as file_cls
from .mesh import mesh as mesh_cls
from .server import server as server_cls
from .setup import setup as setup_cls
from .solution import solution as solution_cls
from .results import results as results_cls
from .parametric_studies import parametric_studies as parametric_studies_cls
from .current_parametric_study import current_parametric_study as current_parametric_study_cls
from .parallel_1 import parallel as parallel_cls
from .report_1 import report as report_cls

class root(Group):
    fluent_name = ...
    child_names = ...
    file: file_cls = ...
    mesh: mesh_cls = ...
    server: server_cls = ...
    setup: setup_cls = ...
    solution: solution_cls = ...
    results: results_cls = ...
    parametric_studies: parametric_studies_cls = ...
    current_parametric_study: current_parametric_study_cls = ...
    parallel: parallel_cls = ...
    report: report_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .particle_drag import particle_drag as particle_drag_cls
from .particle_rotation import particle_rotation as particle_rotation_cls
from .heat_transfer import heat_transfer as heat_transfer_cls
from .custom_laws import custom_laws as custom_laws_cls
from .turbulent_dispersion import turbulent_dispersion as turbulent_dispersion_cls
from .droplet_breakup import droplet_breakup as droplet_breakup_cls

class physical_models(Group):
    """
    'physical_models' child.
    """

    fluent_name = "physical-models"

    child_names = \
        ['particle_drag', 'particle_rotation', 'heat_transfer', 'custom_laws',
         'turbulent_dispersion', 'droplet_breakup']

    _child_classes = dict(
        particle_drag=particle_drag_cls,
        particle_rotation=particle_rotation_cls,
        heat_transfer=heat_transfer_cls,
        custom_laws=custom_laws_cls,
        turbulent_dispersion=turbulent_dispersion_cls,
        droplet_breakup=droplet_breakup_cls,
    )

    return_type = "<object object at 0x7fad5e816d90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enhanced_numerics import enhanced_numerics as enhanced_numerics_cls
from .alternate_bc_formulation import alternate_bc_formulation as alternate_bc_formulation_cls
from .analytical_thermodynamic_derivatives import analytical_thermodynamic_derivatives as analytical_thermodynamic_derivatives_cls

class compressible_flow(Group):
    fluent_name = ...
    child_names = ...
    enhanced_numerics: enhanced_numerics_cls = ...
    alternate_bc_formulation: alternate_bc_formulation_cls = ...
    analytical_thermodynamic_derivatives: analytical_thermodynamic_derivatives_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .averaging_coefficient import averaging_coefficient as averaging_coefficient_cls
from .binary_diffusivity import binary_diffusivity as binary_diffusivity_cls

class film_averaged(Group):
    fluent_name = ...
    child_names = ...
    averaging_coefficient: averaging_coefficient_cls = ...
    binary_diffusivity: binary_diffusivity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_11 import phase as phase_cls
from .thermal_bc import thermal_bc as thermal_bc_cls
from .temperature_1 import temperature as temperature_cls
from .q import q as q_cls

class network_end_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    thermal_bc: thermal_bc_cls = ...
    temperature: temperature_cls = ...
    q: q_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pre_exponential_factor import pre_exponential_factor as pre_exponential_factor_cls
from .activation_energy import activation_energy as activation_energy_cls
from .weighting_factor import weighting_factor as weighting_factor_cls

class first_rate(Group):
    """
    'first_rate' child.
    """

    fluent_name = "first-rate"

    child_names = \
        ['pre_exponential_factor', 'activation_energy', 'weighting_factor']

    _child_classes = dict(
        pre_exponential_factor=pre_exponential_factor_cls,
        activation_energy=activation_energy_cls,
        weighting_factor=weighting_factor_cls,
    )

    return_type = "<object object at 0x7fad5d85f250>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .field import field as field_cls
from .options_7 import options as options_cls
from .enabled_2 import enabled as enabled_cls
from .filter_minimum import filter_minimum as filter_minimum_cls
from .filter_maximum import filter_maximum as filter_maximum_cls

class filter_settings(Group):
    """
    'filter_settings' child.
    """

    fluent_name = "filter-settings"

    child_names = \
        ['field', 'options', 'enabled', 'filter_minimum', 'filter_maximum']

    _child_classes = dict(
        field=field_cls,
        options=options_cls,
        enabled=enabled_cls,
        filter_minimum=filter_minimum_cls,
        filter_maximum=filter_maximum_cls,
    )

    return_type = "<object object at 0x7f83271582c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .use import use as use_cls
from .use_user_define_value import use_user_define_value as use_user_define_value_cls
from .value import value as value_cls

class solid_thread_weight(Group):
    """
    Use solid thread weights.
    """

    fluent_name = "solid-thread-weight"

    child_names = \
        ['use', 'use_user_define_value', 'value']

    _child_classes = dict(
        use=use_cls,
        use_user_define_value=use_user_define_value_cls,
        value=value_cls,
    )

    return_type = "<object object at 0x7fad5c839400>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_9 import options as options_cls
from .range import range as range_cls
from .style_attribute import style_attribute as style_attribute_cls
from .accuracy_control_1 import accuracy_control as accuracy_control_cls
from .plot_1 import plot as plot_cls
from .step import step as step_cls
from .skip import skip as skip_cls
from .coarsen_1 import coarsen as coarsen_cls
from .onzone import onzone as onzone_cls
from .onphysics import onphysics as onphysics_cls
from .field import field as field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .velocity_domain import velocity_domain as velocity_domain_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics_1 import physics as physics_cls
from .geometry_4 import geometry as geometry_cls
from .surfaces_3 import surfaces as surfaces_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_3 import display as display_cls
from .update_min_max import update_min_max as update_min_max_cls

class pathline_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    uid: uid_cls = ...
    options: options_cls = ...
    range: range_cls = ...
    style_attribute: style_attribute_cls = ...
    accuracy_control: accuracy_control_cls = ...
    plot: plot_cls = ...
    step: step_cls = ...
    skip: skip_cls = ...
    coarsen: coarsen_cls = ...
    onzone: onzone_cls = ...
    onphysics: onphysics_cls = ...
    field: field_cls = ...
    surfaces_list: surfaces_list_cls = ...
    velocity_domain: velocity_domain_cls = ...
    color_map: color_map_cls = ...
    draw_mesh: draw_mesh_cls = ...
    mesh_object: mesh_object_cls = ...
    display_state_name: display_state_name_cls = ...
    physics: physics_cls = ...
    geometry: geometry_cls = ...
    surfaces: surfaces_cls = ...
    axes: axes_cls = ...
    curves: curves_cls = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    def update_min_max(self, ):
        """
        'update_min_max' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .domain_1 import domain as domain_cls
from .cell_zones_5 import cell_zones as cell_zones_cls
from .registers import registers as registers_cls
from .variable import variable as variable_cls
from .reference_frame_4 import reference_frame as reference_frame_cls
from .use_custom_field_function import use_custom_field_function as use_custom_field_function_cls
from .custom_field_function_name import custom_field_function_name as custom_field_function_name_cls
from .value_5 import value as value_cls

class calculate_patch(Command):
    fluent_name = ...
    argument_names = ...
    domain: domain_cls = ...
    cell_zones: cell_zones_cls = ...
    registers: registers_cls = ...
    variable: variable_cls = ...
    reference_frame: reference_frame_cls = ...
    use_custom_field_function: use_custom_field_function_cls = ...
    custom_field_function_name: custom_field_function_name_cls = ...
    value: value_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .use import use as use_cls
from .auto_1 import auto as auto_cls
from .threshold import threshold as threshold_cls
from .interval import interval as interval_cls

class dynamic_mesh(Group):
    """
    Use load balancing for dynamic mesh?.
    """

    fluent_name = "dynamic-mesh"

    child_names = \
        ['use', 'auto', 'threshold', 'interval']

    _child_classes = dict(
        use=use_cls,
        auto=auto_cls,
        threshold=threshold_cls,
        interval=interval_cls,
    )

    return_type = "<object object at 0x7fad5c839830>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pre_sweeps_2 import pre_sweeps as pre_sweeps_cls
from .post_sweeps_1 import post_sweeps as post_sweeps_cls
from .max_cycle_1 import max_cycle as max_cycle_cls

class fixed_cycle_parameters(Group):
    fluent_name = ...
    child_names = ...
    pre_sweeps: pre_sweeps_cls = ...
    post_sweeps: post_sweeps_cls = ...
    max_cycle: max_cycle_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .constant import constant as constant_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .polynomial import polynomial as polynomial_cls
from .user_defined_4 import user_defined as user_defined_cls

class diffuse_solar_irradiation(Group):
    """
    'diffuse_solar_irradiation' child.
    """

    fluent_name = "diffuse-solar-irradiation"

    child_names = \
        ['option', 'constant', 'piecewise_linear', 'polynomial',
         'user_defined']

    _child_classes = dict(
        option=option_cls,
        constant=constant_cls,
        piecewise_linear=piecewise_linear_cls,
        polynomial=polynomial_cls,
        user_defined=user_defined_cls,
    )

    return_type = "<object object at 0x7f0b2e8816d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .east_x import east_x as east_x_cls
from .east_y import east_y as east_y_cls
from .east_z import east_z as east_z_cls

class east_direction(Group):
    fluent_name = ...
    child_names = ...
    east_x: east_x_cls = ...
    east_y: east_y_cls = ...
    east_z: east_z_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .x_format import x_format as x_format_cls
from .x_axis_precision import x_axis_precision as x_axis_precision_cls
from .y_format import y_format as y_format_cls
from .y_axis_precision import y_axis_precision as y_axis_precision_cls

class numbers(Group):
    fluent_name = ...
    child_names = ...
    x_format: x_format_cls = ...
    x_axis_precision: x_axis_precision_cls = ...
    y_format: y_format_cls = ...
    y_axis_precision: y_axis_precision_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .coupled_solver import coupled_solver as coupled_solver_cls
from .segregated_solver import segregated_solver as segregated_solver_cls
from .density_based_solver import density_based_solver as density_based_solver_cls

class formulation(Group):
    """
    Select the pseudo time step size formulation for the pseudo time method.
    """

    fluent_name = "formulation"

    child_names = \
        ['coupled_solver', 'segregated_solver', 'density_based_solver']

    _child_classes = dict(
        coupled_solver=coupled_solver_cls,
        segregated_solver=segregated_solver_cls,
        density_based_solver=density_based_solver_cls,
    )

    return_type = "<object object at 0x7fad5c848580>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .setup_reduction import setup_reduction as setup_reduction_cls
from .pick_sample_to_reduce import pick_sample_to_reduce as pick_sample_to_reduce_cls
from .reduce_picked_sample import reduce_picked_sample as reduce_picked_sample_cls

class reduction(Group):
    fluent_name = ...
    child_names = ...
    setup_reduction: setup_reduction_cls = ...
    command_names = ...

    def pick_sample_to_reduce(self, change_curr_sample: bool, sample: str):
        """
        Pick a sample for which to first set-up and then perform the data reduction.
        
        Parameters
        ----------
            change_curr_sample : bool
                'change_curr_sample' child.
            sample : str
                'sample' child.
        
        """

    def reduce_picked_sample(self, check_reduction_wt: bool, file_name: str, overwrite: bool):
        """
        Reduce a sample after first picking it and setting up all data-reduction options and parameters.
        
        Parameters
        ----------
            check_reduction_wt : bool
                'check_reduction_wt' child.
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .variable_lewis_number import variable_lewis_number as variable_lewis_number_cls
from .use_vapor_species_heat_capacity import use_vapor_species_heat_capacity as use_vapor_species_heat_capacity_cls

class convection_diffusion_controlled(Group):
    fluent_name = ...
    child_names = ...
    variable_lewis_number: variable_lewis_number_cls = ...
    use_vapor_species_heat_capacity: use_vapor_species_heat_capacity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .min_pressure import min_pressure as min_pressure_cls
from .max_pressure import max_pressure as max_pressure_cls
from .min_temperature import min_temperature as min_temperature_cls
from .max_temperature import max_temperature as max_temperature_cls
from .min_tke import min_tke as min_tke_cls
from .min_lam_tke import min_lam_tke as min_lam_tke_cls
from .min_des_tke import min_des_tke as min_des_tke_cls
from .min_epsilon import min_epsilon as min_epsilon_cls
from .min_des_epsilon import min_des_epsilon as min_des_epsilon_cls
from .min_v2f_tke import min_v2f_tke as min_v2f_tke_cls
from .min_v2f_epsilon import min_v2f_epsilon as min_v2f_epsilon_cls
from .min_vel_var_scale import min_vel_var_scale as min_vel_var_scale_cls
from .min_elliptic_relax_func import min_elliptic_relax_func as min_elliptic_relax_func_cls
from .min_omega import min_omega as min_omega_cls
from .min_des_omega import min_des_omega as min_des_omega_cls
from .max_turb_visc_ratio import max_turb_visc_ratio as max_turb_visc_ratio_cls
from .positivity_rate import positivity_rate as positivity_rate_cls
from .min_vol_frac_for_matrix_sol import min_vol_frac_for_matrix_sol as min_vol_frac_for_matrix_sol_cls

class limits(Group):
    fluent_name = ...
    child_names = ...
    min_pressure: min_pressure_cls = ...
    max_pressure: max_pressure_cls = ...
    min_temperature: min_temperature_cls = ...
    max_temperature: max_temperature_cls = ...
    min_tke: min_tke_cls = ...
    min_lam_tke: min_lam_tke_cls = ...
    min_des_tke: min_des_tke_cls = ...
    min_epsilon: min_epsilon_cls = ...
    min_des_epsilon: min_des_epsilon_cls = ...
    min_v2f_tke: min_v2f_tke_cls = ...
    min_v2f_epsilon: min_v2f_epsilon_cls = ...
    min_vel_var_scale: min_vel_var_scale_cls = ...
    min_elliptic_relax_func: min_elliptic_relax_func_cls = ...
    min_omega: min_omega_cls = ...
    min_des_omega: min_des_omega_cls = ...
    max_turb_visc_ratio: max_turb_visc_ratio_cls = ...
    positivity_rate: positivity_rate_cls = ...
    min_vol_frac_for_matrix_sol: min_vol_frac_for_matrix_sol_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .cavitation import cavitation as cavitation_cls
from .evaporation_condensation import evaporation_condensation as evaporation_condensation_cls
from .boiling import boiling as boiling_cls
from .area_density_1 import area_density as area_density_cls
from .alternative_energy_treatment import alternative_energy_treatment as alternative_energy_treatment_cls

class heat_mass_transfer(Group):
    fluent_name = ...
    child_names = ...
    cavitation: cavitation_cls = ...
    evaporation_condensation: evaporation_condensation_cls = ...
    boiling: boiling_cls = ...
    area_density: area_density_cls = ...
    alternative_energy_treatment: alternative_energy_treatment_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .use_weighting import use_weighting as use_weighting_cls
from .make_steady_from_unsteady_file import make_steady_from_unsteady_file as make_steady_from_unsteady_file_cls
from .weighting_variable import weighting_variable as weighting_variable_cls
from .reset_min_and_max import reset_min_and_max as reset_min_and_max_cls
from .set_minimum import set_minimum as set_minimum_cls
from .set_maximum import set_maximum as set_maximum_cls
from .use_logarithmic import use_logarithmic as use_logarithmic_cls
from .number_of_bins import number_of_bins as number_of_bins_cls
from .all_variables_number_of_bins import all_variables_number_of_bins as all_variables_number_of_bins_cls
from .list_settings import list_settings as list_settings_cls

class setup_reduction(Group):
    fluent_name = ...
    child_names = ...
    use_weighting: use_weighting_cls = ...
    make_steady_from_unsteady_file: make_steady_from_unsteady_file_cls = ...
    command_names = ...

    def weighting_variable(self, change_curr_sample: bool, sample: str):
        """
        Choose the weighting variable for the averaging in each bin in the data reduction.
        
        Parameters
        ----------
            change_curr_sample : bool
                'change_curr_sample' child.
            sample : str
                'sample' child.
        
        """

    def reset_min_and_max(self, sample_var: str, reset_range: bool):
        """
        Reset the min and max values of the range to be considered for a specific variable in the data reduction.
        
        Parameters
        ----------
            sample_var : str
                'sample_var' child.
            reset_range : bool
                'reset_range' child.
        
        """

    def set_minimum(self, sample_var: str, min_val: float | str):
        """
        Set the minimum value of the range to be considered for a specific variable in the data reduction.
        
        Parameters
        ----------
            sample_var : str
                'sample_var' child.
            min_val : real
                'min_val' child.
        
        """

    def set_maximum(self, sample_var: str, max_val: float | str):
        """
        'set_maximum' command.
        
        Parameters
        ----------
            sample_var : str
                'sample_var' child.
            max_val : real
                'max_val' child.
        
        """

    def use_logarithmic(self, sample_var: str, enable_log: bool):
        """
        Switch on or off logarithmic scaling to be used for a specific variable in the data reduction.
        
        Parameters
        ----------
            sample_var : str
                'sample_var' child.
            enable_log : bool
                'enable_log' child.
        
        """

    def number_of_bins(self, sample_var: str, num_bins: int):
        """
        Set the number of bins to be used for a specific variable in the data reduction.
        
        Parameters
        ----------
            sample_var : str
                'sample_var' child.
            num_bins : int
                'num_bins' child.
        
        """

    def all_variables_number_of_bins(self, all_var_num_of_bins: int):
        """
        Set the number of bins to be used for ALL variables in the data reduction.
        
        Parameters
        ----------
            all_var_num_of_bins : int
                'all_var_num_of_bins' child.
        
        """

    def list_settings(self, ):
        """
        List all user inputs for the sample picked for data reduction.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_2 import name as name_cls
from .method_2 import method as method_cls
from .x_1 import x as x_cls
from .y_1 import y as y_cls
from .z_1 import z as z_cls
from .point_vector import point_vector as point_vector_cls
from .point_normal import point_normal as point_normal_cls
from .compute_from_view_plane import compute_from_view_plane as compute_from_view_plane_cls
from .surface_aligned_normal import surface_aligned_normal as surface_aligned_normal_cls
from .p0 import p0 as p0_cls
from .p1 import p1 as p1_cls
from .p2 import p2 as p2_cls
from .bounded import bounded as bounded_cls
from .sample_point import sample_point as sample_point_cls
from .edges import edges as edges_cls

class plane_surface_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    method: method_cls = ...
    x: x_cls = ...
    y: y_cls = ...
    z: z_cls = ...
    point_vector: point_vector_cls = ...
    point_normal: point_normal_cls = ...
    compute_from_view_plane: compute_from_view_plane_cls = ...
    surface_aligned_normal: surface_aligned_normal_cls = ...
    p0: p0_cls = ...
    p1: p1_cls = ...
    p2: p2_cls = ...
    bounded: bounded_cls = ...
    sample_point: sample_point_cls = ...
    edges: edges_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .formulation import formulation as formulation_cls
from .relaxation_method_1 import relaxation_method as relaxation_method_cls
from .convergence_acceleration_for_stretched_meshes_1 import convergence_acceleration_for_stretched_meshes as convergence_acceleration_for_stretched_meshes_cls
from .relaxation_bounds import relaxation_bounds as relaxation_bounds_cls

class pseudo_time_method(Group):
    """
    Enter the pseudo time method menu.
    """

    fluent_name = "pseudo-time-method"

    child_names = \
        ['formulation', 'relaxation_method',
         'convergence_acceleration_for_stretched_meshes']

    command_names = \
        ['relaxation_bounds']

    _child_classes = dict(
        formulation=formulation_cls,
        relaxation_method=relaxation_method_cls,
        convergence_acceleration_for_stretched_meshes=convergence_acceleration_for_stretched_meshes_cls,
        relaxation_bounds=relaxation_bounds_cls,
    )

    return_type = "<object object at 0x7fad5c848650>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .fluid_1 import fluid as fluid_cls
from .solid_1 import solid as solid_cls

class cell_zone_conditions(Group):
    """
    'cell_zone_conditions' child.
    """

    fluent_name = "cell-zone-conditions"

    child_names = \
        ['fluid', 'solid']

    _child_classes = dict(
        fluid=fluid_cls,
        solid=solid_cls,
    )

    return_type = "<object object at 0x7f8340afaf60>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .scale_1 import scale as scale_cls
from .sphere_lod import sphere_lod as sphere_lod_cls
from .options_8 import options as options_cls

class sphere_settings(Group):
    """
    'sphere_settings' child.
    """

    fluent_name = "sphere-settings"

    child_names = \
        ['scale', 'sphere_lod', 'options']

    _child_classes = dict(
        scale=scale_cls,
        sphere_lod=sphere_lod_cls,
        options=options_cls,
    )

    return_type = "<object object at 0x7f8327158550>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name import name as name_cls
from .field import field as field_cls
from .vector_field import vector_field as vector_field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .lic_color_by_field import lic_color_by_field as lic_color_by_field_cls
from .lic_color import lic_color as lic_color_cls
from .lic_oriented import lic_oriented as lic_oriented_cls
from .lic_normalize import lic_normalize as lic_normalize_cls
from .lic_pixel_interpolation import lic_pixel_interpolation as lic_pixel_interpolation_cls
from .lic_max_steps import lic_max_steps as lic_max_steps_cls
from .texture_spacing import texture_spacing as texture_spacing_cls
from .texture_size import texture_size as texture_size_cls
from .lic_intensity_factor import lic_intensity_factor as lic_intensity_factor_cls
from .lic_image_filter import lic_image_filter as lic_image_filter_cls
from .lic_intensity_alpha import lic_intensity_alpha as lic_intensity_alpha_cls
from .lic_fast import lic_fast as lic_fast_cls
from .gray_scale import gray_scale as gray_scale_cls
from .image_to_display import image_to_display as image_to_display_cls
from .range_option import range_option as range_option_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .display_1 import display as display_cls

class lic_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    field: field_cls = ...
    vector_field: vector_field_cls = ...
    surfaces_list: surfaces_list_cls = ...
    lic_color_by_field: lic_color_by_field_cls = ...
    lic_color: lic_color_cls = ...
    lic_oriented: lic_oriented_cls = ...
    lic_normalize: lic_normalize_cls = ...
    lic_pixel_interpolation: lic_pixel_interpolation_cls = ...
    lic_max_steps: lic_max_steps_cls = ...
    texture_spacing: texture_spacing_cls = ...
    texture_size: texture_size_cls = ...
    lic_intensity_factor: lic_intensity_factor_cls = ...
    lic_image_filter: lic_image_filter_cls = ...
    lic_intensity_alpha: lic_intensity_alpha_cls = ...
    lic_fast: lic_fast_cls = ...
    gray_scale: gray_scale_cls = ...
    image_to_display: image_to_display_cls = ...
    range_option: range_option_cls = ...
    color_map: color_map_cls = ...
    draw_mesh: draw_mesh_cls = ...
    mesh_object: mesh_object_cls = ...
    display_state_name: display_state_name_cls = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_9 import enable as enable_cls
from .disable_1 import disable as disable_cls
from .copy_2 import copy as copy_cls
from .delete_1 import delete as delete_cls
from .export_1 import export as export_cls
from .import__1 import import_ as import__cls

class execute_commands(Group):
    """
    'execute_commands' child.
    """

    fluent_name = "execute-commands"

    command_names = \
        ['enable', 'disable', 'copy', 'delete', 'export', 'import_']

    _child_classes = dict(
        enable=enable_cls,
        disable=disable_cls,
        copy=copy_cls,
        delete=delete_cls,
        export=export_cls,
        import_=import__cls,
    )

    return_type = "<object object at 0x7fad5c84a510>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .anode_pl_zone_list import anode_pl_zone_list as anode_pl_zone_list_cls
from .anode_pl_update import anode_pl_update as anode_pl_update_cls
from .anode_pl_material import anode_pl_material as anode_pl_material_cls
from .anode_pl_porosity import anode_pl_porosity as anode_pl_porosity_cls
from .anode_pl_kr import anode_pl_kr as anode_pl_kr_cls

class anode_pl_zone(Group):
    fluent_name = ...
    child_names = ...
    anode_pl_zone_list: anode_pl_zone_list_cls = ...
    anode_pl_update: anode_pl_update_cls = ...
    anode_pl_material: anode_pl_material_cls = ...
    anode_pl_porosity: anode_pl_porosity_cls = ...
    anode_pl_kr: anode_pl_kr_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .first_to_second_order_blending import first_to_second_order_blending as first_to_second_order_blending_cls
from .first_to_second_order_blending_list import first_to_second_order_blending_list as first_to_second_order_blending_list_cls
from .scheme import scheme as scheme_cls
from .flow_skew_diffusion_exclude import flow_skew_diffusion_exclude as flow_skew_diffusion_exclude_cls
from .scalars_skew_diffusion_exclude import scalars_skew_diffusion_exclude as scalars_skew_diffusion_exclude_cls
from .rhie_chow_flux_specify import rhie_chow_flux_specify as rhie_chow_flux_specify_cls
from .rhie_chow_method import rhie_chow_method as rhie_chow_method_cls

class spatial(Group):
    """
    'spatial' child.
    """

    fluent_name = "spatial"

    child_names = \
        ['first_to_second_order_blending',
         'first_to_second_order_blending_list', 'scheme',
         'flow_skew_diffusion_exclude', 'scalars_skew_diffusion_exclude',
         'rhie_chow_flux_specify', 'rhie_chow_method']

    _child_classes = dict(
        first_to_second_order_blending=first_to_second_order_blending_cls,
        first_to_second_order_blending_list=first_to_second_order_blending_list_cls,
        scheme=scheme_cls,
        flow_skew_diffusion_exclude=flow_skew_diffusion_exclude_cls,
        scalars_skew_diffusion_exclude=scalars_skew_diffusion_exclude_cls,
        rhie_chow_flux_specify=rhie_chow_flux_specify_cls,
        rhie_chow_method=rhie_chow_method_cls,
    )

    return_type = "<object object at 0x7f8327258b20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .options import options as options_cls
from .name import name as name_cls
from .surfaces import surfaces as surfaces_cls
from .cell_func_domain import cell_func_domain as cell_func_domain_cls

class fieldview_unstruct_surfaces(Command):
    """
    Write a Fieldview unstructured surface mesh, data.
    
    Parameters
    ----------
        options : str
            'options' child.
        name : str
            'name' child.
        surfaces : List
            'surfaces' child.
        cell_func_domain : List
            'cell_func_domain' child.
    
    """

    fluent_name = "fieldview-unstruct-surfaces"

    argument_names = \
        ['options', 'name', 'surfaces', 'cell_func_domain']

    _child_classes = dict(
        options=options_cls,
        name=name_cls,
        surfaces=surfaces_cls,
        cell_func_domain=cell_func_domain_cls,
    )

    return_type = "<object object at 0x7f0b2e883bd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .project_filename import project_filename as project_filename_cls

class new(Command):
    """
    Create New Project.
    
    Parameters
    ----------
        project_filename : str
            'project_filename' child.
    
    """

    fluent_name = "new"

    argument_names = \
        ['project_filename']

    _child_classes = dict(
        project_filename=project_filename_cls,
    )

    return_type = "<object object at 0x7fad5e816940>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pressure_corr_grad import pressure_corr_grad as pressure_corr_grad_cls
from .face_pressure_calculation_method import face_pressure_calculation_method as face_pressure_calculation_method_cls
from .exclude_transient_term_in_face_pressure_calc import exclude_transient_term_in_face_pressure_calc as exclude_transient_term_in_face_pressure_calc_cls

class face_pressure_options(Group):
    """
    'face_pressure_options' child.
    """

    fluent_name = "face-pressure-options"

    child_names = \
        ['pressure_corr_grad', 'face_pressure_calculation_method',
         'exclude_transient_term_in_face_pressure_calc']

    _child_classes = dict(
        pressure_corr_grad=pressure_corr_grad_cls,
        face_pressure_calculation_method=face_pressure_calculation_method_cls,
        exclude_transient_term_in_face_pressure_calc=exclude_transient_term_in_face_pressure_calc_cls,
    )

    return_type = "<object object at 0x7f8327259820>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .rgb_vector import rgb_vector as rgb_vector_cls

class set_ambient_color(Command):
    """
    'set_ambient_color' command.
    
    Parameters
    ----------
        rgb_vector : Tuple
            'rgb_vector' child.
    
    """

    fluent_name = "set-ambient-color"

    argument_names = \
        ['rgb_vector']

    _child_classes = dict(
        rgb_vector=rgb_vector_cls,
    )

    return_type = "<object object at 0x7fad5c942000>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pseudo_transient import pseudo_transient as pseudo_transient_cls
from .p_v_coupling import p_v_coupling as p_v_coupling_cls
from .hybrid_nita import hybrid_nita as hybrid_nita_cls
from .equation_order import equation_order as equation_order_cls
from .anti_diffusion import anti_diffusion as anti_diffusion_cls

class advanced_stability_controls(Group):
    """
    Stability controls for multiphase flow.
    """

    fluent_name = "advanced-stability-controls"

    child_names = \
        ['pseudo_transient', 'p_v_coupling', 'hybrid_nita', 'equation_order',
         'anti_diffusion']

    _child_classes = dict(
        pseudo_transient=pseudo_transient_cls,
        p_v_coupling=p_v_coupling_cls,
        hybrid_nita=hybrid_nita_cls,
        equation_order=equation_order_cls,
        anti_diffusion=anti_diffusion_cls,
    )

    return_type = "<object object at 0x7fad5c848080>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .cell_function_1 import cell_function as cell_function_cls
from .load_distribution import load_distribution as load_distribution_cls
from .merge import merge as merge_cls
from .partition_origin_vector import partition_origin_vector as partition_origin_vector_cls
from .pre_test_1 import pre_test as pre_test_cls
from .smooth_1 import smooth as smooth_cls
from .print_verbosity import print_verbosity as print_verbosity_cls
from .origin import origin as origin_cls
from .laplace_smoothing import laplace_smoothing as laplace_smoothing_cls
from .nfaces_as_weights_1 import nfaces_as_weights as nfaces_as_weights_cls
from .face_area_as_weights import face_area_as_weights as face_area_as_weights_cls
from .layering import layering as layering_cls
from .solid_thread_weight import solid_thread_weight as solid_thread_weight_cls
from .stretched_mesh_enhancement import stretched_mesh_enhancement as stretched_mesh_enhancement_cls
from .particle_weight import particle_weight as particle_weight_cls
from .vof_free_surface_weight import vof_free_surface_weight as vof_free_surface_weight_cls
from .isat_weight import isat_weight as isat_weight_cls
from .fluid_solid_rebalance_after_read_case import fluid_solid_rebalance_after_read_case as fluid_solid_rebalance_after_read_case_cls
from .model_weighted_partition import model_weighted_partition as model_weighted_partition_cls
from .dpm_load_balancing import dpm_load_balancing as dpm_load_balancing_cls
from .across_zones_1 import across_zones as across_zones_cls
from .all_off import all_off as all_off_cls
from .all_on import all_on as all_on_cls

class set(Group):
    fluent_name = ...
    child_names = ...
    cell_function: cell_function_cls = ...
    load_distribution: load_distribution_cls = ...
    merge: merge_cls = ...
    partition_origin_vector: partition_origin_vector_cls = ...
    pre_test: pre_test_cls = ...
    smooth: smooth_cls = ...
    print_verbosity: print_verbosity_cls = ...
    origin: origin_cls = ...
    laplace_smoothing: laplace_smoothing_cls = ...
    nfaces_as_weights: nfaces_as_weights_cls = ...
    face_area_as_weights: face_area_as_weights_cls = ...
    layering: layering_cls = ...
    solid_thread_weight: solid_thread_weight_cls = ...
    stretched_mesh_enhancement: stretched_mesh_enhancement_cls = ...
    particle_weight: particle_weight_cls = ...
    vof_free_surface_weight: vof_free_surface_weight_cls = ...
    isat_weight: isat_weight_cls = ...
    fluid_solid_rebalance_after_read_case: fluid_solid_rebalance_after_read_case_cls = ...
    model_weighted_partition: model_weighted_partition_cls = ...
    dpm_load_balancing: dpm_load_balancing_cls = ...
    command_names = ...

    def across_zones(self, across_zone_boundaries: bool):
        """
        Enable partitioning by zone or by domain.
        
        Parameters
        ----------
            across_zone_boundaries : bool
                'across_zone_boundaries' child.
        
        """

    def all_off(self, ):
        """
        Disable all optimization.
        """

    def all_on(self, ):
        """
        Enable all optimization.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .study_name import study_name as study_name_cls

class set_as_current(Command):
    """
    Set As Current Study.
    
    Parameters
    ----------
        study_name : str
            'study_name' child.
    
    """

    fluent_name = "set-as-current"

    argument_names = \
        ['study_name']

    _child_classes = dict(
        study_name=study_name_cls,
    )

    return_type = "<object object at 0x7f0b2c1cf920>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .field import field as field_cls
from .vector_field import vector_field as vector_field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .scale_1 import scale as scale_cls
from .style import style as style_cls
from .skip import skip as skip_cls
from .vector_opt import vector_opt as vector_opt_cls
from .range_option import range_option as range_option_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics_1 import physics as physics_cls
from .geometry_4 import geometry as geometry_cls
from .surfaces_3 import surfaces as surfaces_cls
from .display_3 import display as display_cls
from .update_min_max import update_min_max as update_min_max_cls

class vector_child(Group):
    """
    'child_object_type' of vector.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'vector_field', 'surfaces_list', 'scale', 'style',
         'skip', 'vector_opt', 'range_option', 'color_map', 'draw_mesh',
         'mesh_object', 'display_state_name', 'physics', 'geometry',
         'surfaces']

    command_names = \
        ['display', 'update_min_max']

    _child_classes = dict(
        name=name_cls,
        field=field_cls,
        vector_field=vector_field_cls,
        surfaces_list=surfaces_list_cls,
        scale=scale_cls,
        style=style_cls,
        skip=skip_cls,
        vector_opt=vector_opt_cls,
        range_option=range_option_cls,
        color_map=color_map_cls,
        draw_mesh=draw_mesh_cls,
        mesh_object=mesh_object_cls,
        display_state_name=display_state_name_cls,
        physics=physics_cls,
        geometry=geometry_cls,
        surfaces=surfaces_cls,
        display=display_cls,
        update_min_max=update_min_max_cls,
    )

    return_type = "<object object at 0x7f0b2c2e2230>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .check_reduction_wt import check_reduction_wt as check_reduction_wt_cls
from .file_name_1 import file_name as file_name_cls
from .overwrite import overwrite as overwrite_cls

class reduce_picked_sample(Command):
    """
    Reduce a sample after first picking it and setting up all data-reduction options and parameters.
    
    Parameters
    ----------
        check_reduction_wt : bool
            'check_reduction_wt' child.
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "reduce-picked-sample"

    argument_names = \
        ['check_reduction_wt', 'file_name', 'overwrite']

    _child_classes = dict(
        check_reduction_wt=check_reduction_wt_cls,
        file_name=file_name_cls,
        overwrite=overwrite_cls,
    )

    return_type = "<object object at 0x7fad5c943d60>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .old_props import old_props as old_props_cls
from .file_name_2 import file_name as file_name_cls
from .frequency import frequency as frequency_cls
from .flow_frequency import flow_frequency as flow_frequency_cls
from .itr_index import itr_index as itr_index_cls
from .run_index import run_index as run_index_cls
from .frequency_of import frequency_of as frequency_of_cls
from .report_defs import report_defs as report_defs_cls
from .print_1 import print as print_cls
from .active import active as active_cls
from .write_instantaneous_values import write_instantaneous_values as write_instantaneous_values_cls

class report_files_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    old_props: old_props_cls = ...
    file_name: file_name_cls = ...
    frequency: frequency_cls = ...
    flow_frequency: flow_frequency_cls = ...
    itr_index: itr_index_cls = ...
    run_index: run_index_cls = ...
    frequency_of: frequency_of_cls = ...
    report_defs: report_defs_cls = ...
    print: print_cls = ...
    active: active_cls = ...
    write_instantaneous_values: write_instantaneous_values_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_high_res_tracking import enable_high_res_tracking as enable_high_res_tracking_cls
from .expert_options_1 import expert_options as expert_options_cls
from .high_res_tracking_options import high_res_tracking_options as high_res_tracking_options_cls
from .tracking_parameters import tracking_parameters as tracking_parameters_cls
from .track_in_absolute_frame import track_in_absolute_frame as track_in_absolute_frame_cls

class tracking(Group):
    """
    Main menu to control the time integration of the particle trajectory equations.
    """

    fluent_name = "tracking"

    child_names = \
        ['enable_high_res_tracking', 'expert_options',
         'high_res_tracking_options', 'tracking_parameters',
         'track_in_absolute_frame']

    _child_classes = dict(
        enable_high_res_tracking=enable_high_res_tracking_cls,
        expert_options=expert_options_cls,
        high_res_tracking_options=high_res_tracking_options_cls,
        tracking_parameters=tracking_parameters_cls,
        track_in_absolute_frame=track_in_absolute_frame_cls,
    )

    return_type = "<object object at 0x7fad5e815b70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .porous_media import porous_media as porous_media_cls
from .compressible_flow import compressible_flow as compressible_flow_cls
from .boiling_parameters import boiling_parameters as boiling_parameters_cls
from .viscous_flow import viscous_flow as viscous_flow_cls
from .heat_mass_transfer import heat_mass_transfer as heat_mass_transfer_cls
from .advanced_stability_controls import advanced_stability_controls as advanced_stability_controls_cls
from .default_controls import default_controls as default_controls_cls
from .face_pressure_controls import face_pressure_controls as face_pressure_controls_cls
from .solution_stabilization import solution_stabilization as solution_stabilization_cls

class multiphase_numerics(Group):
    """
    Enter the multiphase numerics options menu.
    """

    fluent_name = "multiphase-numerics"

    child_names = \
        ['porous_media', 'compressible_flow', 'boiling_parameters',
         'viscous_flow', 'heat_mass_transfer', 'advanced_stability_controls',
         'default_controls', 'face_pressure_controls',
         'solution_stabilization']

    _child_classes = dict(
        porous_media=porous_media_cls,
        compressible_flow=compressible_flow_cls,
        boiling_parameters=boiling_parameters_cls,
        viscous_flow=viscous_flow_cls,
        heat_mass_transfer=heat_mass_transfer_cls,
        advanced_stability_controls=advanced_stability_controls_cls,
        default_controls=default_controls_cls,
        face_pressure_controls=face_pressure_controls_cls,
        solution_stabilization=solution_stabilization_cls,
    )

    return_type = "<object object at 0x7f0b2c4fbae0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .options import options as options_cls
from .domain_val import domain_val as domain_val_cls
from .all_wall_zones import all_wall_zones as all_wall_zones_cls
from .wall_thread_list import wall_thread_list as wall_thread_list_cls
from .direction_vector_1 import direction_vector as direction_vector_cls
from .momentum_center import momentum_center as momentum_center_cls
from .momentum_axis import momentum_axis as momentum_axis_cls
from .pressure_coordinate import pressure_coordinate as pressure_coordinate_cls
from .coord_val import coord_val as coord_val_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_data import append_data as append_data_cls
from .overwrite import overwrite as overwrite_cls

class forces(Command):
    """
    'forces' command.
    
    Parameters
    ----------
        options : str
            'options' child.
        domain_val : str
            'domain_val' child.
        all_wall_zones : bool
            Select all wall zones available.
        wall_thread_list : List
            'wall_thread_list' child.
        direction_vector : List
            'direction_vector' child.
        momentum_center : List
            'momentum_center' child.
        momentum_axis : List
            'momentum_axis' child.
        pressure_coordinate : str
            'pressure_coordinate' child.
        coord_val : real
            'coord_val' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_data : bool
            'append_data' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "forces"

    argument_names = \
        ['options', 'domain_val', 'all_wall_zones', 'wall_thread_list',
         'direction_vector', 'momentum_center', 'momentum_axis',
         'pressure_coordinate', 'coord_val', 'write_to_file', 'file_name',
         'append_data', 'overwrite']

    _child_classes = dict(
        options=options_cls,
        domain_val=domain_val_cls,
        all_wall_zones=all_wall_zones_cls,
        wall_thread_list=wall_thread_list_cls,
        direction_vector=direction_vector_cls,
        momentum_center=momentum_center_cls,
        momentum_axis=momentum_axis_cls,
        pressure_coordinate=pressure_coordinate_cls,
        coord_val=coord_val_cls,
        write_to_file=write_to_file_cls,
        file_name=file_name_cls,
        append_data=append_data_cls,
        overwrite=overwrite_cls,
    )

    return_type = "<object object at 0x7f0b2c1cf5b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enabled_4 import enabled as enabled_cls
from .tolerance import tolerance as tolerance_cls
from .max_num_refinements import max_num_refinements as max_num_refinements_cls
from .step_size_fraction import step_size_fraction as step_size_fraction_cls

class accuracy_control(Group):
    fluent_name = ...
    child_names = ...
    enabled: enabled_cls = ...
    tolerance: tolerance_cls = ...
    max_num_refinements: max_num_refinements_cls = ...
    step_size_fraction: step_size_fraction_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .execute_settings_optimization import execute_settings_optimization as execute_settings_optimization_cls
from .execute_advanced_stabilization import execute_advanced_stabilization as execute_advanced_stabilization_cls
from .additional_stabilization_controls import additional_stabilization_controls as additional_stabilization_controls_cls
from .execute_additional_stability_controls import execute_additional_stability_controls as execute_additional_stability_controls_cls
from .velocity_limiting_treatment import velocity_limiting_treatment as velocity_limiting_treatment_cls

class solution_stabilization(Group):
    """
    VOF solution stabilization menu.
    """

    fluent_name = "solution-stabilization"

    child_names = \
        ['execute_settings_optimization', 'execute_advanced_stabilization',
         'additional_stabilization_controls',
         'execute_additional_stability_controls',
         'velocity_limiting_treatment']

    _child_classes = dict(
        execute_settings_optimization=execute_settings_optimization_cls,
        execute_advanced_stabilization=execute_advanced_stabilization_cls,
        additional_stabilization_controls=additional_stabilization_controls_cls,
        execute_additional_stability_controls=execute_additional_stability_controls_cls,
        velocity_limiting_treatment=velocity_limiting_treatment_cls,
    )

    return_type = "<object object at 0x7fad5c848250>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .crossflow_transition import crossflow_transition as crossflow_transition_cls
from .critical_reynolds_number_correlation import critical_reynolds_number_correlation as critical_reynolds_number_correlation_cls
from .clambda_scale import clambda_scale as clambda_scale_cls
from .capg_hightu import capg_hightu as capg_hightu_cls
from .cfpg_hightu import cfpg_hightu as cfpg_hightu_cls
from .capg_lowtu import capg_lowtu as capg_lowtu_cls
from .cfpg_lowtu import cfpg_lowtu as cfpg_lowtu_cls
from .ctu_hightu import ctu_hightu as ctu_hightu_cls
from .ctu_lowtu import ctu_lowtu as ctu_lowtu_cls
from .rec_max import rec_max as rec_max_cls
from .rec_c1 import rec_c1 as rec_c1_cls
from .rec_c2 import rec_c2 as rec_c2_cls
from .cbubble_c1 import cbubble_c1 as cbubble_c1_cls
from .cbubble_c2 import cbubble_c2 as cbubble_c2_cls
from .rv1_switch import rv1_switch as rv1_switch_cls

class transition_model_options(Group):
    fluent_name = ...
    child_names = ...
    crossflow_transition: crossflow_transition_cls = ...
    critical_reynolds_number_correlation: critical_reynolds_number_correlation_cls = ...
    clambda_scale: clambda_scale_cls = ...
    capg_hightu: capg_hightu_cls = ...
    cfpg_hightu: cfpg_hightu_cls = ...
    capg_lowtu: capg_lowtu_cls = ...
    cfpg_lowtu: cfpg_lowtu_cls = ...
    ctu_hightu: ctu_hightu_cls = ...
    ctu_lowtu: ctu_lowtu_cls = ...
    rec_max: rec_max_cls = ...
    rec_c1: rec_c1_cls = ...
    rec_c2: rec_c2_cls = ...
    cbubble_c1: cbubble_c1_cls = ...
    cbubble_c2: cbubble_c2_cls = ...
    rv1_switch: rv1_switch_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .design_point import design_point as design_point_cls

class duplicate(Command):
    """
    Duplicate Design Point.
    
    Parameters
    ----------
        design_point : str
            'design_point' child.
    
    """

    fluent_name = "duplicate"

    argument_names = \
        ['design_point']

    _child_classes = dict(
        design_point=design_point_cls,
    )

    return_type = "<object object at 0x7f8327159630>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_10 import option as option_cls
from .value_1 import value as value_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .polynomial import polynomial as polynomial_cls
from .user_defined_function import user_defined_function as user_defined_function_cls

class diffusivity_1(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    value: value_cls = ...
    piecewise_linear: piecewise_linear_cls = ...
    piecewise_polynomial: piecewise_polynomial_cls = ...
    polynomial: polynomial_cls = ...
    user_defined_function: user_defined_function_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .usage import usage as usage_cls
from .reset_1 import reset as reset_cls

class timer(Group):
    fluent_name = ...
    command_names = ...

    def usage(self, ):
        """
        Print solver timer.
        """

    def reset(self, ):
        """
        Reset domain timers.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_velocity_limiting import enable_velocity_limiting as enable_velocity_limiting_cls
from .set_velocity_and_vof_cutoffs import set_velocity_and_vof_cutoffs as set_velocity_and_vof_cutoffs_cls
from .set_damping_strengths import set_damping_strengths as set_damping_strengths_cls
from .set_velocity_cutoff import set_velocity_cutoff as set_velocity_cutoff_cls
from .set_damping_strength import set_damping_strength as set_damping_strength_cls
from .verbosity_5 import verbosity as verbosity_cls

class velocity_limiting_treatment(Group):
    fluent_name = ...
    child_names = ...
    enable_velocity_limiting: enable_velocity_limiting_cls = ...
    set_velocity_and_vof_cutoffs: set_velocity_and_vof_cutoffs_cls = ...
    set_damping_strengths: set_damping_strengths_cls = ...
    set_velocity_cutoff: set_velocity_cutoff_cls = ...
    set_damping_strength: set_damping_strength_cls = ...
    verbosity: verbosity_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_auto_creation_of_scp_file import enable_auto_creation_of_scp_file as enable_auto_creation_of_scp_file_cls
from .write_sc_file import write_sc_file as write_sc_file_cls

class sc_def_file_settings(Group):
    fluent_name = ...
    child_names = ...
    enable_auto_creation_of_scp_file: enable_auto_creation_of_scp_file_cls = ...
    command_names = ...

    def write_sc_file(self, file_name: str, overwrite: bool):
        """
        Write a Fluent Input File for System Coupling.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pressure_gradient_effects import pressure_gradient_effects as pressure_gradient_effects_cls
from .thermal_effects import thermal_effects as thermal_effects_cls

class enhanced_wall_treatment_options(Group):
    """
    'enhanced_wall_treatment_options' child.
    """

    fluent_name = "enhanced-wall-treatment-options"

    child_names = \
        ['pressure_gradient_effects', 'thermal_effects']

    _child_classes = dict(
        pressure_gradient_effects=pressure_gradient_effects_cls,
        thermal_effects=thermal_effects_cls,
    )

    return_type = "<object object at 0x7f83499c9320>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .input_params import input_params as input_params_cls
from .function_name import function_name as function_name_cls
from .average_over import average_over as average_over_cls
from .old_props import old_props as old_props_cls

class user_defined_child(Group):
    """
    'child_object_type' of user_defined.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['retain_instantaneous_values', 'input_params', 'function_name',
         'average_over', 'old_props']

    _child_classes = dict(
        retain_instantaneous_values=retain_instantaneous_values_cls,
        input_params=input_params_cls,
        function_name=function_name_cls,
        average_over=average_over_cls,
        old_props=old_props_cls,
    )

    return_type = "<object object at 0x7fad5c848fc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .material import material as material_cls
from .sources import sources as sources_cls
from .source_terms import source_terms as source_terms_cls
from .fixed import fixed as fixed_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .fixes import fixes as fixes_cls
from .motion_spec import motion_spec as motion_spec_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .omega import omega as omega_cls
from .axis_origin_component import axis_origin_component as axis_origin_component_cls
from .axis_direction_component import axis_direction_component as axis_direction_component_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .mrf_motion import mrf_motion as mrf_motion_cls
from .mrf_relative_to_thread import mrf_relative_to_thread as mrf_relative_to_thread_cls
from .mrf_omega import mrf_omega as mrf_omega_cls
from .reference_frame_velocity_components import reference_frame_velocity_components as reference_frame_velocity_components_cls
from .reference_frame_axis_origin_components import reference_frame_axis_origin_components as reference_frame_axis_origin_components_cls
from .reference_frame_axis_direction_components import reference_frame_axis_direction_components as reference_frame_axis_direction_components_cls
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name as mrf_udf_zmotion_name_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_motion import mgrid_motion as mgrid_motion_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity_components import moving_mesh_velocity_components as moving_mesh_velocity_components_cls
from .moving_mesh_axis_origin_components import moving_mesh_axis_origin_components as moving_mesh_axis_origin_components_cls
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name as mgrid_udf_zmotion_name_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_motion_velocity_components import solid_motion_velocity_components as solid_motion_velocity_components_cls
from .solid_motion_axis_origin_components import solid_motion_axis_origin_components as solid_motion_axis_origin_components_cls
from .solid_motion_axis_direction_components import solid_motion_axis_direction_components as solid_motion_axis_direction_components_cls
from .solid_udf_zmotion_name import solid_udf_zmotion_name as solid_udf_zmotion_name_cls
from .radiating import radiating as radiating_cls
from .les_embedded import les_embedded as les_embedded_cls
from .contact_property import contact_property as contact_property_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .cursys import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
from .pcb_model import pcb_model as pcb_model_cls
from .pcb_zone_info import pcb_zone_info as pcb_zone_info_cls

class phase_child(Group):
    fluent_name = ...
    child_names = ...
    material: material_cls = ...
    sources: sources_cls = ...
    source_terms: source_terms_cls = ...
    fixed: fixed_cls = ...
    cylindrical_fixed_var: cylindrical_fixed_var_cls = ...
    fixes: fixes_cls = ...
    motion_spec: motion_spec_cls = ...
    relative_to_thread: relative_to_thread_cls = ...
    omega: omega_cls = ...
    axis_origin_component: axis_origin_component_cls = ...
    axis_direction_component: axis_direction_component_cls = ...
    udf_zmotion_name: udf_zmotion_name_cls = ...
    mrf_motion: mrf_motion_cls = ...
    mrf_relative_to_thread: mrf_relative_to_thread_cls = ...
    mrf_omega: mrf_omega_cls = ...
    reference_frame_velocity_components: reference_frame_velocity_components_cls = ...
    reference_frame_axis_origin_components: reference_frame_axis_origin_components_cls = ...
    reference_frame_axis_direction_components: reference_frame_axis_direction_components_cls = ...
    mrf_udf_zmotion_name: mrf_udf_zmotion_name_cls = ...
    mgrid_enable_transient: mgrid_enable_transient_cls = ...
    mgrid_motion: mgrid_motion_cls = ...
    mgrid_relative_to_thread: mgrid_relative_to_thread_cls = ...
    mgrid_omega: mgrid_omega_cls = ...
    moving_mesh_velocity_components: moving_mesh_velocity_components_cls = ...
    moving_mesh_axis_origin_components: moving_mesh_axis_origin_components_cls = ...
    mgrid_udf_zmotion_name: mgrid_udf_zmotion_name_cls = ...
    solid_motion: solid_motion_cls = ...
    solid_relative_to_thread: solid_relative_to_thread_cls = ...
    solid_omega: solid_omega_cls = ...
    solid_motion_velocity_components: solid_motion_velocity_components_cls = ...
    solid_motion_axis_origin_components: solid_motion_axis_origin_components_cls = ...
    solid_motion_axis_direction_components: solid_motion_axis_direction_components_cls = ...
    solid_udf_zmotion_name: solid_udf_zmotion_name_cls = ...
    radiating: radiating_cls = ...
    les_embedded: les_embedded_cls = ...
    contact_property: contact_property_cls = ...
    vapor_phase_realgas: vapor_phase_realgas_cls = ...
    cursys: cursys_cls = ...
    cursys_name: cursys_name_cls = ...
    pcb_model: pcb_model_cls = ...
    pcb_zone_info: pcb_zone_info_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .process_count import process_count as process_count_cls
from .host_name import host_name as host_name_cls

class helper_session_setup(Group):
    """
    Setup helper session for multidomain conjugate heat transfer.
    """

    fluent_name = "helper-session-setup"

    child_names = \
        ['process_count', 'host_name']

    _child_classes = dict(
        process_count=process_count_cls,
        host_name=host_name_cls,
    )

    return_type = "<object object at 0x7fad5c8399a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_2 import list as list_cls
from .list_properties_5 import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .set_1 import set as set_cls
from .register_based_child import register_based_child


class register_based(NamedObject[register_based_child], CreatableNamedObjectMixinOld[register_based_child]):
    """
    Set up the application of poor mesh numerics to cells in a register.
    """

    fluent_name = "register-based"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'set']

    _child_classes = dict(
        list=list_cls,
        list_properties=list_properties_cls,
        duplicate=duplicate_cls,
        set=set_cls,
    )

    child_object_type: register_based_child = register_based_child
    """
    child_object_type of register_based.
    """
    return_type = "<object object at 0x7f0b2c2e00e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .alpha import alpha as alpha_cls
from .dm import dm as dm_cls
from .c2 import c2 as c2_cls
from .thermal_ctk import thermal_ctk as thermal_ctk_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .v_absp import v_absp as v_absp_cls
from .ir_absp import ir_absp as ir_absp_cls
from .ir_trans import ir_trans as ir_trans_cls
from .v_trans import v_trans as v_trans_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls
from .jump_adhesion import jump_adhesion as jump_adhesion_cls
from .adhesion_constrained import adhesion_constrained as adhesion_constrained_cls
from .adhesion_angle import adhesion_angle as adhesion_angle_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls

class phase_child(Group):
    fluent_name = ...
    child_names = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = ...
    alpha: alpha_cls = ...
    dm: dm_cls = ...
    c2: c2_cls = ...
    thermal_ctk: thermal_ctk_cls = ...
    solar_fluxes: solar_fluxes_cls = ...
    v_absp: v_absp_cls = ...
    ir_absp: ir_absp_cls = ...
    ir_trans: ir_trans_cls = ...
    v_trans: v_trans_cls = ...
    dpm_bc_type: dpm_bc_type_cls = ...
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = ...
    reinj_inj: reinj_inj_cls = ...
    dpm_bc_udf: dpm_bc_udf_cls = ...
    strength: strength_cls = ...
    jump_adhesion: jump_adhesion_cls = ...
    adhesion_constrained: adhesion_constrained_cls = ...
    adhesion_angle: adhesion_angle_cls = ...
    x_displacement_type: x_displacement_type_cls = ...
    x_displacement_value: x_displacement_value_cls = ...
    y_displacement_type: y_displacement_type_cls = ...
    y_displacement_value: y_displacement_value_cls = ...
    z_displacement_type: z_displacement_type_cls = ...
    z_displacement_value: z_displacement_value_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class jpeg_hardcopy_quality(Integer):
    """
    0  : Saves lowest quality jpeg image, but with the least file size.
    100: Saves highest quality jpeg image, but with the maximum file size.
    """

    fluent_name = "jpeg-hardcopy-quality"

    return_type = "<object object at 0x7f8327158d10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .axis_direction_child import axis_direction_child


class axis_origin(ListObject[axis_direction_child]):
    """
    'axis_origin' child.
    """

    fluent_name = "axis-origin"

    child_object_type: axis_direction_child = axis_direction_child
    """
    child_object_type of axis_origin.
    """
    return_type = "<object object at 0x7fad5d4f2fd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .pseudo_time_settings import pseudo_time_settings as pseudo_time_settings_cls
from .iter_count_2 import iter_count as iter_count_cls
from .adaptive_time_stepping import adaptive_time_stepping as adaptive_time_stepping_cls
from .cfl_based_adaptive_time_stepping import cfl_based_adaptive_time_stepping as cfl_based_adaptive_time_stepping_cls
from .reporting_interval import reporting_interval as reporting_interval_cls
from .time_step_count_1 import time_step_count as time_step_count_cls
from .transient_controls import transient_controls as transient_controls_cls
from .data_sampling_1 import data_sampling as data_sampling_cls
from .data_sampling_options import data_sampling_options as data_sampling_options_cls
from .residual_verbosity import residual_verbosity as residual_verbosity_cls
from .calculate import calculate as calculate_cls
from .interrupt import interrupt as interrupt_cls
from .dual_time_iterate import dual_time_iterate as dual_time_iterate_cls
from .iterate import iterate as iterate_cls
from .iterating import iterating as iterating_cls

class run_calculation(Group):
    fluent_name = ...
    child_names = ...
    pseudo_time_settings: pseudo_time_settings_cls = ...
    iter_count: iter_count_cls = ...
    adaptive_time_stepping: adaptive_time_stepping_cls = ...
    cfl_based_adaptive_time_stepping: cfl_based_adaptive_time_stepping_cls = ...
    reporting_interval: reporting_interval_cls = ...
    time_step_count: time_step_count_cls = ...
    transient_controls: transient_controls_cls = ...
    data_sampling: data_sampling_cls = ...
    data_sampling_options: data_sampling_options_cls = ...
    residual_verbosity: residual_verbosity_cls = ...
    command_names = ...

    def calculate(self, ):
        """
        'calculate' command.
        """

    def interrupt(self, end_of_timestep: bool):
        """
        Interrupt the iterations.
        
        Parameters
        ----------
            end_of_timestep : bool
                'end_of_timestep' child.
        
        """

    def dual_time_iterate(self, total_period_count: int, time_step_count: int, total_time_step_count: int, total_time: float | str, incremental_time: float | str, max_iter_per_step: int, postprocess: bool, post_iter_per_time_step_count: int):
        """
        Perform unsteady iterations.
        
        Parameters
        ----------
            total_period_count : int
                Set number of total periods.
            time_step_count : int
                Set inceremtal number of Time steps.
            total_time_step_count : int
                Set total number of Time steps.
            total_time : real
                Set Total Simulation Time.
            incremental_time : real
                Set Incremental Time.
            max_iter_per_step : int
                Set Maximum Number of iterations per time step.
            postprocess : bool
                Enable/Disable Postprocess pollutant solution?.
            post_iter_per_time_step_count : int
                Set Number of post-processing iterations per time step.
        
        """

    def iterate(self, iter_count: int):
        """
        Perform a specified number of iterations.
        
        Parameters
        ----------
            iter_count : int
                Set incremental number of time steps.
        
        """

    query_names = ...

    def iterating(self, ):
        """
        'iterating' query.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .style import style as style_cls
from .line_width import line_width as line_width_cls
from .arrow_space import arrow_space as arrow_space_cls
from .arrow_scale import arrow_scale as arrow_scale_cls
from .marker_size import marker_size as marker_size_cls
from .sphere_size import sphere_size as sphere_size_cls
from .sphere_lod import sphere_lod as sphere_lod_cls
from .radius import radius as radius_cls
from .ribbon_settings import ribbon_settings as ribbon_settings_cls
from .sphere_settings import sphere_settings as sphere_settings_cls

class style_attribute(Group):
    fluent_name = ...
    child_names = ...
    style: style_cls = ...
    line_width: line_width_cls = ...
    arrow_space: arrow_space_cls = ...
    arrow_scale: arrow_scale_cls = ...
    marker_size: marker_size_cls = ...
    sphere_size: sphere_size_cls = ...
    sphere_lod: sphere_lod_cls = ...
    radius: radius_cls = ...
    ribbon_settings: ribbon_settings_cls = ...
    sphere_settings: sphere_settings_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .kc import kc as kc_cls
from .hc import hc as hc_cls
from .t_1 import t as t_cls
from .q_1 import q as q_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .strength import strength as strength_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'kc', 'hc', 't', 'q',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'strength']

    _child_classes = dict(
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        porous_jump_turb_wall_treatment=porous_jump_turb_wall_treatment_cls,
        kc=kc_cls,
        hc=hc_cls,
        t=t_cls,
        q=q_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        strength=strength_cls,
    )

    return_type = "<object object at 0x7fad5cd77390>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .density_3 import density as density_cls
from .thermal_conductivity_3 import thermal_conductivity as thermal_conductivity_cls
from .vaporization_model import vaporization_model as vaporization_model_cls
from .thermolysis_model import thermolysis_model as thermolysis_model_cls
from .latent_heat_1 import latent_heat as latent_heat_cls
from .volatile_fraction import volatile_fraction as volatile_fraction_cls
from .heat_of_pyrolysis import heat_of_pyrolysis as heat_of_pyrolysis_cls
from .specific_heat_3 import specific_heat as specific_heat_cls
from .binary_diffusivity_1 import binary_diffusivity as binary_diffusivity_cls
from .diffusivity_reference_pressure import diffusivity_reference_pressure as diffusivity_reference_pressure_cls
from .averaging_coefficient_t import averaging_coefficient_t as averaging_coefficient_t_cls
from .averaging_coefficient_y import averaging_coefficient_y as averaging_coefficient_y_cls
from .vapor_pressure import vapor_pressure as vapor_pressure_cls
from .molecular_weight_1 import molecular_weight as molecular_weight_cls
from .vaporization_temperature import vaporization_temperature as vaporization_temperature_cls
from .boiling_point import boiling_point as boiling_point_cls
from .thermophoretic_co import thermophoretic_co as thermophoretic_co_cls
from .scattering_factor_1 import scattering_factor as scattering_factor_cls
from .emissivity_1 import emissivity as emissivity_cls
from .viscosity_2 import viscosity as viscosity_cls
from .dpm_surften_1 import dpm_surften as dpm_surften_cls
from .electric_conductivity_1 import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity_1 import dual_electric_conductivity as dual_electric_conductivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .charge_density import charge_density as charge_density_cls

class droplet_particle_child(Group):
    """
    'child_object_type' of droplet_particle.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'thermal_conductivity', 'vaporization_model',
         'thermolysis_model', 'latent_heat', 'volatile_fraction',
         'heat_of_pyrolysis', 'specific_heat', 'binary_diffusivity',
         'diffusivity_reference_pressure', 'averaging_coefficient_t',
         'averaging_coefficient_y', 'vapor_pressure', 'molecular_weight',
         'vaporization_temperature', 'boiling_point', 'thermophoretic_co',
         'scattering_factor', 'emissivity', 'viscosity', 'dpm_surften',
         'electric_conductivity', 'dual_electric_conductivity',
         'magnetic_permeability', 'charge_density']

    _child_classes = dict(
        density=density_cls,
        thermal_conductivity=thermal_conductivity_cls,
        vaporization_model=vaporization_model_cls,
        thermolysis_model=thermolysis_model_cls,
        latent_heat=latent_heat_cls,
        volatile_fraction=volatile_fraction_cls,
        heat_of_pyrolysis=heat_of_pyrolysis_cls,
        specific_heat=specific_heat_cls,
        binary_diffusivity=binary_diffusivity_cls,
        diffusivity_reference_pressure=diffusivity_reference_pressure_cls,
        averaging_coefficient_t=averaging_coefficient_t_cls,
        averaging_coefficient_y=averaging_coefficient_y_cls,
        vapor_pressure=vapor_pressure_cls,
        molecular_weight=molecular_weight_cls,
        vaporization_temperature=vaporization_temperature_cls,
        boiling_point=boiling_point_cls,
        thermophoretic_co=thermophoretic_co_cls,
        scattering_factor=scattering_factor_cls,
        emissivity=emissivity_cls,
        viscosity=viscosity_cls,
        dpm_surften=dpm_surften_cls,
        electric_conductivity=electric_conductivity_cls,
        dual_electric_conductivity=dual_electric_conductivity_cls,
        magnetic_permeability=magnetic_permeability_cls,
        charge_density=charge_density_cls,
    )

    return_type = "<object object at 0x7fad5d85ea90>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class model_tip_loss(Integer):
    """
    Select Tip Loss Model:
    
     - Enter 1 if using Quadratic model 
     - Enter 2 if using modified Prandtl model 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "model-tip-loss"

    return_type = "<object object at 0x7fad5e814e30>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .report_files import report_files as report_files_cls
from .report_plots import report_plots as report_plots_cls
from .convergence_conditions import convergence_conditions as convergence_conditions_cls

class monitor(Group):
    fluent_name = ...
    child_names = ...
    report_files: report_files_cls = ...
    report_plots: report_plots_cls = ...
    convergence_conditions: convergence_conditions_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .invalidate_case import invalidate_case as invalidate_case_cls
from .delete_all_compute_nodes import delete_all_compute_nodes as delete_all_compute_nodes_cls

class kill_all_nodes(Command):
    """
    Delete all compute nodes from virtual machine.
    
    Parameters
    ----------
        invalidate_case : bool
            'invalidate_case' child.
        delete_all_compute_nodes : bool
            'delete_all_compute_nodes' child.
    
    """

    fluent_name = "kill-all-nodes"

    argument_names = \
        ['invalidate_case', 'delete_all_compute_nodes']

    _child_classes = dict(
        invalidate_case=invalidate_case_cls,
        delete_all_compute_nodes=delete_all_compute_nodes_cls,
    )

    return_type = "<object object at 0x7f0b2c0dc6c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .auto_time_step_size_cal import auto_time_step_size_cal as auto_time_step_size_cal_cls
from .pseudo_time_step_size import pseudo_time_step_size as pseudo_time_step_size_cls
from .options_length_scale_calc_methods import options_length_scale_calc_methods as options_length_scale_calc_methods_cls
from .auto_time_step_size_scale_factor import auto_time_step_size_scale_factor as auto_time_step_size_scale_factor_cls
from .length_scale import length_scale as length_scale_cls
from .auto_time_size_calc_solid_zone import auto_time_size_calc_solid_zone as auto_time_size_calc_solid_zone_cls
from .auto_time_solid_scale_factor import auto_time_solid_scale_factor as auto_time_solid_scale_factor_cls
from .time_step_size_for_solid_zone import time_step_size_for_solid_zone as time_step_size_for_solid_zone_cls

class global_time_step_settings(Group):
    fluent_name = ...
    child_names = ...
    auto_time_step_size_cal: auto_time_step_size_cal_cls = ...
    pseudo_time_step_size: pseudo_time_step_size_cls = ...
    options_length_scale_calc_methods: options_length_scale_calc_methods_cls = ...
    auto_time_step_size_scale_factor: auto_time_step_size_scale_factor_cls = ...
    length_scale: length_scale_cls = ...
    auto_time_size_calc_solid_zone: auto_time_size_calc_solid_zone_cls = ...
    auto_time_solid_scale_factor: auto_time_solid_scale_factor_cls = ...
    time_step_size_for_solid_zone: time_step_size_for_solid_zone_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .n_smooth_for_interfacial_regims import n_smooth_for_interfacial_regims as n_smooth_for_interfacial_regims_cls
from .sm_relax_factor import sm_relax_factor as sm_relax_factor_cls
from .viscous_func_options import viscous_func_options as viscous_func_options_cls
from .density_func_options import density_func_options as density_func_options_cls
from .exponent_smoothing_func import exponent_smoothing_func as exponent_smoothing_func_cls
from .exponent_density_func import exponent_density_func as exponent_density_func_cls
from .boundry_treatment import boundry_treatment as boundry_treatment_cls
from .near_wall_treatment_1 import near_wall_treatment as near_wall_treatment_cls

class interfacial_artificial_viscosity(Group):
    fluent_name = ...
    child_names = ...
    n_smooth_for_interfacial_regims: n_smooth_for_interfacial_regims_cls = ...
    sm_relax_factor: sm_relax_factor_cls = ...
    viscous_func_options: viscous_func_options_cls = ...
    density_func_options: density_func_options_cls = ...
    exponent_smoothing_func: exponent_smoothing_func_cls = ...
    exponent_density_func: exponent_density_func_cls = ...
    boundry_treatment: boundry_treatment_cls = ...
    near_wall_treatment: near_wall_treatment_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .schnerr_evap_coeff import schnerr_evap_coeff as schnerr_evap_coeff_cls
from .schnerr_cond_coeff import schnerr_cond_coeff as schnerr_cond_coeff_cls
from .max_vapor_pressure_ratio import max_vapor_pressure_ratio as max_vapor_pressure_ratio_cls
from .min_vapor_pressure import min_vapor_pressure as min_vapor_pressure_cls
from .display_clipped_pressure import display_clipped_pressure as display_clipped_pressure_cls
from .turbulent_diffusion import turbulent_diffusion as turbulent_diffusion_cls
from .old_treatment_for_turbulent_diffusion import old_treatment_for_turbulent_diffusion as old_treatment_for_turbulent_diffusion_cls

class cavitation(Group):
    fluent_name = ...
    child_names = ...
    schnerr_evap_coeff: schnerr_evap_coeff_cls = ...
    schnerr_cond_coeff: schnerr_cond_coeff_cls = ...
    max_vapor_pressure_ratio: max_vapor_pressure_ratio_cls = ...
    min_vapor_pressure: min_vapor_pressure_cls = ...
    display_clipped_pressure: display_clipped_pressure_cls = ...
    turbulent_diffusion: turbulent_diffusion_cls = ...
    old_treatment_for_turbulent_diffusion: old_treatment_for_turbulent_diffusion_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .solution_stabilization import solution_stabilization as solution_stabilization_cls
from .verbosity_1 import verbosity as verbosity_cls
from .parameters import parameters as parameters_cls
from .spatial import spatial as spatial_cls
from .transient import transient as transient_cls
from .amg import amg as amg_cls
from .models_2 import models as models_cls
from .methods import methods as methods_cls
from .miscellaneous import miscellaneous as miscellaneous_cls
from .set_settings_to_default import set_settings_to_default as set_settings_to_default_cls

class contact_solution_controls(Group):
    fluent_name = ...
    child_names = ...
    solution_stabilization: solution_stabilization_cls = ...
    verbosity: verbosity_cls = ...
    parameters: parameters_cls = ...
    spatial: spatial_cls = ...
    transient: transient_cls = ...
    amg: amg_cls = ...
    models: models_cls = ...
    methods: methods_cls = ...
    miscellaneous: miscellaneous_cls = ...
    command_names = ...

    def set_settings_to_default(self, ):
        """
        Set contact solution stabilization to default.
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .phase_6 import phase as phase_cls
from .name_2 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .open_channel import open_channel as open_channel_cls
from .inlet_number import inlet_number as inlet_number_cls
from .phase_spec import phase_spec as phase_spec_cls
from .frame_of_reference import frame_of_reference as frame_of_reference_cls
from .gauge_total_pressure import gauge_total_pressure as gauge_total_pressure_cls
from .gauge_pressure import gauge_pressure as gauge_pressure_cls
from .t0 import t0 as t0_cls
from .direction_spec import direction_spec as direction_spec_cls
from .flow_spec import flow_spec as flow_spec_cls
from .ht_local import ht_local as ht_local_cls
from .ht_total import ht_total as ht_total_cls
from .vmag import vmag as vmag_cls
from .ht_bottom import ht_bottom as ht_bottom_cls
from .den_spec import den_spec as den_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .direction_vector import direction_vector as direction_vector_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .les_spec_name import les_spec_name as les_spec_name_cls
from .rfg_number_of_modes import rfg_number_of_modes as rfg_number_of_modes_cls
from .vm_number_of_vortices import vm_number_of_vortices as vm_number_of_vortices_cls
from .vm_streamwise_fluct import vm_streamwise_fluct as vm_streamwise_fluct_cls
from .vm_mass_conservation import vm_mass_conservation as vm_mass_conservation_cls
from .stg_scale_limiter_type import stg_scale_limiter_type as stg_scale_limiter_type_cls
from .stg_ti_limiter import stg_ti_limiter as stg_ti_limiter_cls
from .stg_tvr_limiter import stg_tvr_limiter as stg_tvr_limiter_cls
from .stg_dw_limiter import stg_dw_limiter as stg_dw_limiter_cls
from .volumetric_synthetic_turbulence_generator import volumetric_synthetic_turbulence_generator as volumetric_synthetic_turbulence_generator_cls
from .volumetric_synthetic_turbulence_generator_option import volumetric_synthetic_turbulence_generator_option as volumetric_synthetic_turbulence_generator_option_cls
from .volumetric_synthetic_turbulence_generator_option_thickness import volumetric_synthetic_turbulence_generator_option_thickness as volumetric_synthetic_turbulence_generator_option_thickness_cls
from .prevent_reverse_flow import prevent_reverse_flow as prevent_reverse_flow_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e_1 import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .granular_temperature import granular_temperature as granular_temperature_cls
from .iac import iac as iac_cls
from .lsfun import lsfun as lsfun_cls
from .volume_fraction import volume_fraction as volume_fraction_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .equ_required import equ_required as equ_required_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .pb_disc_bc import pb_disc_bc as pb_disc_bc_cls
from .pb_disc import pb_disc as pb_disc_cls
from .pb_qmom_bc import pb_qmom_bc as pb_qmom_bc_cls
from .pb_qmom import pb_qmom as pb_qmom_cls
from .pb_qbmm_bc import pb_qbmm_bc as pb_qbmm_bc_cls
from .pb_qbmm import pb_qbmm as pb_qbmm_cls
from .pb_smm_bc import pb_smm_bc as pb_smm_bc_cls
from .pb_smm import pb_smm as pb_smm_cls
from .pb_dqmom_bc import pb_dqmom_bc as pb_dqmom_bc_cls
from .pb_dqmom import pb_dqmom as pb_dqmom_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction import radial_direction as radial_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fvar import fvar as fvar_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar2 import fvar2 as fvar2_cls
from .premixc import premixc as premixc_cls
from .premixc_var import premixc_var as premixc_var_cls
from .ecfm_sigma import ecfm_sigma as ecfm_sigma_cls
from .inert import inert as inert_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .tss_scalar import tss_scalar as tss_scalar_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_drop_bccustom import fensapice_drop_bccustom as fensapice_drop_bccustom_cls
from .fensapice_drop_lwc import fensapice_drop_lwc as fensapice_drop_lwc_cls
from .fensapice_drop_dtemp import fensapice_drop_dtemp as fensapice_drop_dtemp_cls
from .fensapice_drop_ddiam import fensapice_drop_ddiam as fensapice_drop_ddiam_cls
from .fensapice_drop_dv import fensapice_drop_dv as fensapice_drop_dv_cls
from .fensapice_drop_dx import fensapice_drop_dx as fensapice_drop_dx_cls
from .fensapice_drop_dy import fensapice_drop_dy as fensapice_drop_dy_cls
from .fensapice_drop_dz import fensapice_drop_dz as fensapice_drop_dz_cls
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection as fensapice_dpm_surface_injection_cls
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream as fensapice_dpm_inj_nstream_cls
from .fensapice_drop_icc import fensapice_drop_icc as fensapice_drop_icc_cls
from .fensapice_drop_ctemp import fensapice_drop_ctemp as fensapice_drop_ctemp_cls
from .fensapice_drop_cmelt import fensapice_drop_cmelt as fensapice_drop_cmelt_cls
from .fensapice_drop_cdiam import fensapice_drop_cdiam as fensapice_drop_cdiam_cls
from .fensapice_drop_cv import fensapice_drop_cv as fensapice_drop_cv_cls
from .fensapice_drop_cx import fensapice_drop_cx as fensapice_drop_cx_cls
from .fensapice_drop_cy import fensapice_drop_cy as fensapice_drop_cy_cls
from .fensapice_drop_cz import fensapice_drop_cz as fensapice_drop_cz_cls
from .fensapice_drop_vrh import fensapice_drop_vrh as fensapice_drop_vrh_cls
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1 as fensapice_drop_vrh_1_cls
from .fensapice_drop_vc import fensapice_drop_vc as fensapice_drop_vc_cls
from .mixing_plane_thread import mixing_plane_thread as mixing_plane_thread_cls
from .wsf import wsf as wsf_cls
from .wsb import wsb as wsb_cls
from .wsn import wsn as wsn_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .ac_options import ac_options as ac_options_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls
from .les_spec import les_spec as les_spec_cls
from .a_1 import a as a_cls
from .swirl_model import swirl_model as swirl_model_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .fan_omega import fan_omega as fan_omega_cls
from .fan_origin import fan_origin as fan_origin_cls
from .strength import strength as strength_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls

class intake_fan_child(Group):
    """
    'child_object_type' of intake_fan.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'open_channel', 'inlet_number', 'phase_spec', 'frame_of_reference',
         'gauge_total_pressure', 'gauge_pressure', 't0', 'direction_spec',
         'flow_spec', 'ht_local', 'ht_total', 'vmag', 'ht_bottom', 'den_spec',
         'coordinate_system', 'flow_direction', 'direction_vector',
         'axis_direction', 'axis_origin', 'les_spec_name',
         'rfg_number_of_modes', 'vm_number_of_vortices',
         'vm_streamwise_fluct', 'vm_mass_conservation',
         'stg_scale_limiter_type', 'stg_ti_limiter', 'stg_tvr_limiter',
         'stg_dw_limiter', 'volumetric_synthetic_turbulence_generator',
         'volumetric_synthetic_turbulence_generator_option',
         'volumetric_synthetic_turbulence_generator_option_thickness',
         'prevent_reverse_flow', 'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e',
         'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'granular_temperature', 'iac', 'lsfun', 'volume_fraction',
         'species_in_mole_fractions', 'mf', 'elec_potential_type',
         'potential_value', 'dual_potential_type', 'dual_potential_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'equ_required', 'uds_bc', 'uds', 'pb_disc_bc', 'pb_disc',
         'pb_qmom_bc', 'pb_qmom', 'pb_qbmm_bc', 'pb_qbmm', 'pb_smm_bc',
         'pb_smm', 'pb_dqmom_bc', 'pb_dqmom', 'radiation_bc',
         'radial_direction', 'coll_dtheta', 'coll_dphi', 'band_q_irrad',
         'band_q_irrad_diffuse', 'parallel_collimated_beam',
         'solar_direction', 'solar_irradiation', 't_b_b_spec', 't_b_b',
         'in_emiss', 'fmean', 'fvar', 'fmean2', 'fvar2', 'premixc',
         'premixc_var', 'ecfm_sigma', 'inert', 'pollut_no', 'pollut_hcn',
         'pollut_nh3', 'pollut_n2o', 'pollut_urea', 'pollut_hnco',
         'pollut_nco', 'pollut_so2', 'pollut_h2s', 'pollut_so3', 'pollut_sh',
         'pollut_so', 'pollut_soot', 'pollut_nuclei', 'pollut_ctar',
         'pollut_hg', 'pollut_hgcl2', 'pollut_hcl', 'pollut_hgo', 'pollut_cl',
         'pollut_cl2', 'pollut_hgcl', 'pollut_hocl', 'tss_scalar',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'fensapice_flow_bc_subtype', 'fensapice_drop_bccustom',
         'fensapice_drop_lwc', 'fensapice_drop_dtemp', 'fensapice_drop_ddiam',
         'fensapice_drop_dv', 'fensapice_drop_dx', 'fensapice_drop_dy',
         'fensapice_drop_dz', 'fensapice_dpm_surface_injection',
         'fensapice_dpm_inj_nstream', 'fensapice_drop_icc',
         'fensapice_drop_ctemp', 'fensapice_drop_cmelt',
         'fensapice_drop_cdiam', 'fensapice_drop_cv', 'fensapice_drop_cx',
         'fensapice_drop_cy', 'fensapice_drop_cz', 'fensapice_drop_vrh',
         'fensapice_drop_vrh_1', 'fensapice_drop_vc', 'mixing_plane_thread',
         'wsf', 'wsb', 'wsn', 'solar_fluxes', 'solar_shining_factor',
         'radiating_s2s_surface', 'ac_options', 'impedance_0', 'impedance_1',
         'impedance_2', 'ac_wave', 'les_spec', 'a', 'swirl_model',
         'swirl_factor', 'fan_omega', 'fan_origin', 'strength',
         'new_fan_definition']

    _child_classes = dict(
        phase=phase_cls,
        name=name_cls,
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        open_channel=open_channel_cls,
        inlet_number=inlet_number_cls,
        phase_spec=phase_spec_cls,
        frame_of_reference=frame_of_reference_cls,
        gauge_total_pressure=gauge_total_pressure_cls,
        gauge_pressure=gauge_pressure_cls,
        t0=t0_cls,
        direction_spec=direction_spec_cls,
        flow_spec=flow_spec_cls,
        ht_local=ht_local_cls,
        ht_total=ht_total_cls,
        vmag=vmag_cls,
        ht_bottom=ht_bottom_cls,
        den_spec=den_spec_cls,
        coordinate_system=coordinate_system_cls,
        flow_direction=flow_direction_cls,
        direction_vector=direction_vector_cls,
        axis_direction=axis_direction_cls,
        axis_origin=axis_origin_cls,
        les_spec_name=les_spec_name_cls,
        rfg_number_of_modes=rfg_number_of_modes_cls,
        vm_number_of_vortices=vm_number_of_vortices_cls,
        vm_streamwise_fluct=vm_streamwise_fluct_cls,
        vm_mass_conservation=vm_mass_conservation_cls,
        stg_scale_limiter_type=stg_scale_limiter_type_cls,
        stg_ti_limiter=stg_ti_limiter_cls,
        stg_tvr_limiter=stg_tvr_limiter_cls,
        stg_dw_limiter=stg_dw_limiter_cls,
        volumetric_synthetic_turbulence_generator=volumetric_synthetic_turbulence_generator_cls,
        volumetric_synthetic_turbulence_generator_option=volumetric_synthetic_turbulence_generator_option_cls,
        volumetric_synthetic_turbulence_generator_option_thickness=volumetric_synthetic_turbulence_generator_option_thickness_cls,
        prevent_reverse_flow=prevent_reverse_flow_cls,
        ke_spec=ke_spec_cls,
        nut=nut_cls,
        kl=kl_cls,
        intermit=intermit_cls,
        k=k_cls,
        e=e_cls,
        o=o_cls,
        v2=v2_cls,
        turb_intensity=turb_intensity_cls,
        turb_length_scale=turb_length_scale_cls,
        turb_hydraulic_diam=turb_hydraulic_diam_cls,
        turb_viscosity_ratio=turb_viscosity_ratio_cls,
        turb_viscosity_ratio_profile=turb_viscosity_ratio_profile_cls,
        rst_spec=rst_spec_cls,
        uu=uu_cls,
        vv=vv_cls,
        ww=ww_cls,
        uv=uv_cls,
        vw=vw_cls,
        uw=uw_cls,
        ksgs_spec=ksgs_spec_cls,
        ksgs=ksgs_cls,
        sgs_turb_intensity=sgs_turb_intensity_cls,
        granular_temperature=granular_temperature_cls,
        iac=iac_cls,
        lsfun=lsfun_cls,
        volume_fraction=volume_fraction_cls,
        species_in_mole_fractions=species_in_mole_fractions_cls,
        mf=mf_cls,
        elec_potential_type=elec_potential_type_cls,
        potential_value=potential_value_cls,
        dual_potential_type=dual_potential_type_cls,
        dual_potential_value=dual_potential_value_cls,
        x_displacement_type=x_displacement_type_cls,
        x_displacement_value=x_displacement_value_cls,
        y_displacement_type=y_displacement_type_cls,
        y_displacement_value=y_displacement_value_cls,
        z_displacement_type=z_displacement_type_cls,
        z_displacement_value=z_displacement_value_cls,
        prob_mode_1=prob_mode_1_cls,
        prob_mode_2=prob_mode_2_cls,
        prob_mode_3=prob_mode_3_cls,
        equ_required=equ_required_cls,
        uds_bc=uds_bc_cls,
        uds=uds_cls,
        pb_disc_bc=pb_disc_bc_cls,
        pb_disc=pb_disc_cls,
        pb_qmom_bc=pb_qmom_bc_cls,
        pb_qmom=pb_qmom_cls,
        pb_qbmm_bc=pb_qbmm_bc_cls,
        pb_qbmm=pb_qbmm_cls,
        pb_smm_bc=pb_smm_bc_cls,
        pb_smm=pb_smm_cls,
        pb_dqmom_bc=pb_dqmom_bc_cls,
        pb_dqmom=pb_dqmom_cls,
        radiation_bc=radiation_bc_cls,
        radial_direction=radial_direction_cls,
        coll_dtheta=coll_dtheta_cls,
        coll_dphi=coll_dphi_cls,
        band_q_irrad=band_q_irrad_cls,
        band_q_irrad_diffuse=band_q_irrad_diffuse_cls,
        parallel_collimated_beam=parallel_collimated_beam_cls,
        solar_direction=solar_direction_cls,
        solar_irradiation=solar_irradiation_cls,
        t_b_b_spec=t_b_b_spec_cls,
        t_b_b=t_b_b_cls,
        in_emiss=in_emiss_cls,
        fmean=fmean_cls,
        fvar=fvar_cls,
        fmean2=fmean2_cls,
        fvar2=fvar2_cls,
        premixc=premixc_cls,
        premixc_var=premixc_var_cls,
        ecfm_sigma=ecfm_sigma_cls,
        inert=inert_cls,
        pollut_no=pollut_no_cls,
        pollut_hcn=pollut_hcn_cls,
        pollut_nh3=pollut_nh3_cls,
        pollut_n2o=pollut_n2o_cls,
        pollut_urea=pollut_urea_cls,
        pollut_hnco=pollut_hnco_cls,
        pollut_nco=pollut_nco_cls,
        pollut_so2=pollut_so2_cls,
        pollut_h2s=pollut_h2s_cls,
        pollut_so3=pollut_so3_cls,
        pollut_sh=pollut_sh_cls,
        pollut_so=pollut_so_cls,
        pollut_soot=pollut_soot_cls,
        pollut_nuclei=pollut_nuclei_cls,
        pollut_ctar=pollut_ctar_cls,
        pollut_hg=pollut_hg_cls,
        pollut_hgcl2=pollut_hgcl2_cls,
        pollut_hcl=pollut_hcl_cls,
        pollut_hgo=pollut_hgo_cls,
        pollut_cl=pollut_cl_cls,
        pollut_cl2=pollut_cl2_cls,
        pollut_hgcl=pollut_hgcl_cls,
        pollut_hocl=pollut_hocl_cls,
        tss_scalar=tss_scalar_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        fensapice_flow_bc_subtype=fensapice_flow_bc_subtype_cls,
        fensapice_drop_bccustom=fensapice_drop_bccustom_cls,
        fensapice_drop_lwc=fensapice_drop_lwc_cls,
        fensapice_drop_dtemp=fensapice_drop_dtemp_cls,
        fensapice_drop_ddiam=fensapice_drop_ddiam_cls,
        fensapice_drop_dv=fensapice_drop_dv_cls,
        fensapice_drop_dx=fensapice_drop_dx_cls,
        fensapice_drop_dy=fensapice_drop_dy_cls,
        fensapice_drop_dz=fensapice_drop_dz_cls,
        fensapice_dpm_surface_injection=fensapice_dpm_surface_injection_cls,
        fensapice_dpm_inj_nstream=fensapice_dpm_inj_nstream_cls,
        fensapice_drop_icc=fensapice_drop_icc_cls,
        fensapice_drop_ctemp=fensapice_drop_ctemp_cls,
        fensapice_drop_cmelt=fensapice_drop_cmelt_cls,
        fensapice_drop_cdiam=fensapice_drop_cdiam_cls,
        fensapice_drop_cv=fensapice_drop_cv_cls,
        fensapice_drop_cx=fensapice_drop_cx_cls,
        fensapice_drop_cy=fensapice_drop_cy_cls,
        fensapice_drop_cz=fensapice_drop_cz_cls,
        fensapice_drop_vrh=fensapice_drop_vrh_cls,
        fensapice_drop_vrh_1=fensapice_drop_vrh_1_cls,
        fensapice_drop_vc=fensapice_drop_vc_cls,
        mixing_plane_thread=mixing_plane_thread_cls,
        wsf=wsf_cls,
        wsb=wsb_cls,
        wsn=wsn_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_shining_factor=solar_shining_factor_cls,
        radiating_s2s_surface=radiating_s2s_surface_cls,
        ac_options=ac_options_cls,
        impedance_0=impedance_0_cls,
        impedance_1=impedance_1_cls,
        impedance_2=impedance_2_cls,
        ac_wave=ac_wave_cls,
        les_spec=les_spec_cls,
        a=a_cls,
        swirl_model=swirl_model_cls,
        swirl_factor=swirl_factor_cls,
        fan_omega=fan_omega_cls,
        fan_origin=fan_origin_cls,
        strength=strength_cls,
        new_fan_definition=new_fan_definition_cls,
    )

    return_type = "<object object at 0x7f0b2dc9b900>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .migrate_and_reorder import migrate_and_reorder as migrate_and_reorder_cls
from .preserve_boundary_layer import preserve_boundary_layer as preserve_boundary_layer_cls
from .preserve_interior_zones import preserve_interior_zones as preserve_interior_zones_cls

class options(Group):
    fluent_name = ...
    child_names = ...
    migrate_and_reorder: migrate_and_reorder_cls = ...
    preserve_boundary_layer: preserve_boundary_layer_cls = ...
    preserve_interior_zones: preserve_interior_zones_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enabled_2 import enabled as enabled_cls
from .stream_id import stream_id as stream_id_cls

class track_single_particle_stream(Group):
    fluent_name = ...
    child_names = ...
    enabled: enabled_cls = ...
    stream_id: stream_id_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .wall_distance_free import wall_distance_free as wall_distance_free_cls
from .cjet import cjet as cjet_cls
from .creal import creal as creal_cls
from .cnw_sub import cnw_sub as cnw_sub_cls
from .cjet_aux import cjet_aux as cjet_aux_cls
from .cbf_lam import cbf_lam as cbf_lam_cls
from .cbf_tur import cbf_tur as cbf_tur_cls
from .geko_defaults import geko_defaults as geko_defaults_cls

class geko_options(Group):
    """
    'geko_options' child.
    """

    fluent_name = "geko-options"

    child_names = \
        ['wall_distance_free', 'cjet', 'creal', 'cnw_sub', 'cjet_aux',
         'cbf_lam', 'cbf_tur']

    command_names = \
        ['geko_defaults']

    _child_classes = dict(
        wall_distance_free=wall_distance_free_cls,
        cjet=cjet_cls,
        creal=creal_cls,
        cnw_sub=cnw_sub_cls,
        cjet_aux=cjet_aux_cls,
        cbf_lam=cbf_lam_cls,
        cbf_tur=cbf_tur_cls,
        geko_defaults=geko_defaults_cls,
    )

    return_type = "<object object at 0x7f0b2e881b20>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .method_2 import method as method_cls
from .number_of_coeff import number_of_coeff as number_of_coeff_cls
from .function_of import function_of as function_of_cls
from .coefficients_1 import coefficients as coefficients_cls
from .value_1 import value as value_cls
from .piecewise_polynomial_1 import piecewise_polynomial as piecewise_polynomial_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls

class a(Group):
    """
    'a' child.
    """

    fluent_name = "a"

    child_names = \
        ['method', 'number_of_coeff', 'function_of', 'coefficients', 'value',
         'piecewise_polynomial', 'piecewise_linear']

    _child_classes = dict(
        method=method_cls,
        number_of_coeff=number_of_coeff_cls,
        function_of=function_of_cls,
        coefficients=coefficients_cls,
        value=value_cls,
        piecewise_polynomial=piecewise_polynomial_cls,
        piecewise_linear=piecewise_linear_cls,
    )

    return_type = "<object object at 0x7f0b2ddc5060>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class gaussian_factor(Real):
    """
    Set a factor for the gaussian kernel for node-based averaging.~%Large values give small size, small values give large size of kernel.
    """

    fluent_name = "gaussian-factor"

    return_type = "<object object at 0x7f0b2d2052d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .command_name_1 import command_name as command_name_cls
from .tsv_file_name import tsv_file_name as tsv_file_name_cls

class export(Command):
    """
    Export execute-commands to a TSV file.
    
    Parameters
    ----------
        command_name : List
            'command_name' child.
        tsv_file_name : str
            'tsv_file_name' child.
    
    """

    fluent_name = "export"

    argument_names = \
        ['command_name', 'tsv_file_name']

    _child_classes = dict(
        command_name=command_name_cls,
        tsv_file_name=tsv_file_name_cls,
    )

    return_type = "<object object at 0x7f0b2c3f3dc0>"
